package cn.estsh.i3plus.ext.mes.pcn.apiservice.serviceimpl.base;

import cn.estsh.i3plus.platform.common.convert.ConvertBean;
import cn.estsh.i3plus.platform.common.tool.TimeTool;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.common.PagerHelper;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesContainerSnStation;
import cn.estsh.i3plus.pojo.mes.repository.MesContainerSnStationRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import cn.estsh.i3plus.ext.mes.pcn.api.base.IMesContainerSnStationService;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.Objects;

/**
 * @Description : 容器条码与站点关系表-业务方法实现
 * @Reference :
 * @Author : logic
 * @CreateDate : 2025/6/13 09:16
 * @Modify:
 **/
@Slf4j
@Service
public class MesContainerSnStationServiceImpl implements IMesContainerSnStationService {

    @Autowired
    private MesContainerSnStationRepository mesContainerSnStationRepository;

    @Override
    public ListPager<MesContainerSnStation> queryPager(MesContainerSnStation mesContainerSnStation, Pager pager) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(mesContainerSnStation.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(mesContainerSnStation.getEquipmentCode(), "equipmentCode", ddlPackBean);
        DdlPreparedPack.getStringEqualPack(mesContainerSnStation.getStation(), "station", ddlPackBean);
        DdlPreparedPack.getStringEqualPack(mesContainerSnStation.getContainerSn(), "containerSn", ddlPackBean);
        DdlPreparedPack.getStringEqualPack(mesContainerSnStation.getPartNo(), "partNo", ddlPackBean);
        pager = PagerHelper.getPager(pager, mesContainerSnStationRepository.findByHqlWhereCount(ddlPackBean));
        List<MesContainerSnStation> containerSnStationList = mesContainerSnStationRepository.findByHqlWherePage(ddlPackBean, pager);
        return new ListPager<>(containerSnStationList, pager);
    }

    @Override
    public void doInsert(MesContainerSnStation mesContainerSnStation, String userName) {
        //根据站点 + 设备代码的组合查询现有数据中最大的顺序号，新增数据的顺序号在最大值的基础上加一
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(mesContainerSnStation.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(mesContainerSnStation.getEquipmentCode(), "equipmentCode", ddlPackBean);
        DdlPreparedPack.getStringEqualPack(mesContainerSnStation.getStation(), "station", ddlPackBean);
        DdlPreparedPack.getOrderByPack(
                new Object[]{CommonEnumUtil.ASC_OR_DESC.DESC.getValue()},
                new String[]{"seq"}, ddlPackBean);
        List<MesContainerSnStation> oldContainerSnStationList =
                mesContainerSnStationRepository.findByHqlTopWhere(ddlPackBean, 1);
        Integer seq;
        if (CollectionUtils.isEmpty(oldContainerSnStationList)) {
            seq = 1;
        }else {
            if (Objects.isNull(oldContainerSnStationList.get(0)) ||
                    Objects.isNull(oldContainerSnStationList.get(0).getSeq())) {
                seq = 1;
            }else {
                seq = oldContainerSnStationList.get(0).getSeq() + 1;
            }
        }
        mesContainerSnStation.setSeq(seq);
        ConvertBean.saveOrUpdate(mesContainerSnStation, userName);
        mesContainerSnStationRepository.insert(mesContainerSnStation);
    }

    @Override
    public void doUpdate(MesContainerSnStation mesContainerSnStation, String userName) {
        ConvertBean.saveOrUpdate(mesContainerSnStation, userName);
        mesContainerSnStationRepository.update(mesContainerSnStation);
    }

    @Override
    public void doUpdateIsValid(List<Long> idList, Integer status, String organizeCode, String userName) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(organizeCode);
        DdlPreparedPack.getInPackList(idList, "id", ddlPackBean);
        mesContainerSnStationRepository.updateByProperties(
                new String[]{"modifyUser", "modifyDatetime", "isValid"},
                new Object[]{userName, TimeTool.getNowTime(true), status },
                ddlPackBean);
    }

    @Override
    public void deleteWeaklyByIds(List<Long> idList, String organizeCode, String userName) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(organizeCode);
        DdlPreparedPack.getInPackList(idList, "id", ddlPackBean);
        mesContainerSnStationRepository.updateByProperties(
                new String[]{"modifyUser", "modifyDatetime", "isDeleted"},
                new Object[]{userName, TimeTool.getNowTime(true), CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue()},
                ddlPackBean);
    }

}
